@@ -2,44 +2,44 @@
 kivy mixin and widgets to integrate a sideloading server in your app
 ====================================================================
 
-This namespace portion provides widgets and a mixin class for you main app instance to easily integrate and control
+this namespace portion provides widgets and a mixin class for you main app instance to easily integrate and control
 the `ae sideloading server <ae.sideloading_server>` into your :class:`main app <ae.kivy.apps.KivyMainApp>`.
 
 
 kivy sideloading integration into your main app class
 -----------------------------------------------------
 
-Add the :class:`SideloadingMainAppMixin` mixin provided by this ae namespace portion to your main app class::
+add the :class:`SideloadingMainAppMixin` mixin provided by this ae namespace portion to your main app class::
 
     class MyMainAppClass(SideloadingMainAppMixin, KivyMainApp):
 
-The sub app of the sideloading server will then automatically be instantiated when your app starts and will initialize
+the sub app of the sideloading server will then automatically be instantiated when your app starts and will initialize
 the :attr:`~SideloadingMainAppMixin.sideloading_app` attribute with this sub app instance.
 
 .. hint::
-    If you prefer to instantiate the sideloading server sub app manually then specify :class:`SideloadingMainAppMixin`
+    if you prefer to instantiate the sideloading server sub app manually then specify :class:`SideloadingMainAppMixin`
     after :class:`~ae.kivy.apps.KivyMainApp` in the declaration of your main app class.
 
-Adding `sideloading_active` to the `:ref:`app state variables` of your app's :ref:`config files` will ensure that the
+adding `sideloading_active` to the `:ref:`app state variables` of your app's :ref:`config files` will ensure that the
 running status of the sideloading server gets automatically stored persistent on pause or stop of the app for the next
 app start.
 
-The running status of the sideloading server will be restored in the app start event handler method
+the running status of the sideloading server will be restored in the app start event handler method
 (:meth:`~SideloadingMainAppMixin.on_app_run`).
 
-To manually start it offering the APK of the embedding app call the
+to manually start it offering the APK of the embedding app call the
 :meth:`~SideloadingMainAppMixin.on_sideloading_server_start` method passing an empty string and dict::
 
     self.on_sideloading_server_start("", {})
 
 .. hint:: when you pass the dict with a number in a 'port' key then this number will be used as server listening port.
 
-If no 'port' gets specified then :class:`SideloadingMainAppMixin` will calculate an individual port number from the
-first character of the :attr:`~ae.core.AppBase.app_name` of the app mixing in this class. This is to prevent
+if no 'port' gets specified then :class:`SideloadingMainAppMixin` will calculate an individual port number from the
+first character of the :attr:`~ae.core.AppBase.app_name` of the app mixing in this class. this is to prevent
 the server socket error `[Errno 98] Address already in use` if two different applications with sideloading are
 running on the same device and want to offer sideloading.
 
-To manually pause the sideloading server call the
+to manually pause the sideloading server call the
 :meth:`~SideloadingMainAppMixin.on_sideloading_server_stop` method passing an empty string and dict::
 
     self.on_sideloading_server_stop("", {})
@@ -48,7 +48,7 @@ To manually pause the sideloading server call the
 usage of the sideloading button
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-This ae namespace portion is additionally providing the `SideloadingButton` flow button widget to integrate it in
+this ae namespace portion is additionally providing the `SideloadingButton` flow button widget to integrate it in
 your Kivy app. This button can be used to:
 
 * start or stop the sideloading server,
@@ -56,7 +56,7 @@ your Kivy app. This button can be used to:
 * display file info like full file path and file length.
 * display the URL of your sideloading server as QR code to allow connections from other devices.
 
-To optionally integrate this `SideloadingButton` into your app add it to the root layout in your app's main kv file
+to optionally integrate this `SideloadingButton` into your app add it to the root layout in your app's main kv file
 with the `id` `sideloading_button`::
 
     MyRootLayout:
@@ -64,11 +64,11 @@ with the `id` `sideloading_button`::
         SideloadingButton:
             id: sideloading_button
 
-If the sideloading server is not active and the user is clicking the `SideloadingButton` then this portion will
+if the sideloading server is not active and the user is clicking the `SideloadingButton` then this portion will
 first check if the `Downloads` folder of the device is containing an APK file for the running app and if yes then the
 sideloading server will be started providing the found APK file.
 
-If the sideloading server is instead already running/active and the user is tapping on the `SideloadingButton` then a
+ff the sideloading server is instead already running/active and the user is tapping on the `SideloadingButton` then a
 dropdown menu will be shown with options to (1) display info of the sideloading file, (2) select a new file, (3)
 display the sideloading server URL as QR code or (4) stop the sideloading server.
 
@@ -76,7 +76,7 @@ display the sideloading server URL as QR code or (4) stop the sideloading server
 dependencies/requirements in `buildozer.spec`
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-To build an Android APK with the kivy sideloading server integrated, make sure that the following external packages
+to build an Android APK with the kivy sideloading server integrated, make sure that the following external packages
 are specified in the `requirements` setting of the `[app]` section of your `buildozer.spec` file.
 
 * ae.kivy_file_chooser
@@ -87,11 +87,9 @@ are specified in the `requirements` setting of the `[app]` section of your `buil
 * kivy_garden.qrcode
 * qrcode
 
-Additionally, all the packages and ae namespace portions required by the above packages have to be included. E.g. the
-`GlslTester demo app <https://gibhub.com/AndiEcker/GlslTester>`_ includes the following packages::
+additionally, the following packages and ae namespace portions required by the above packages have to be included::
 
-    requirements = android, hostpython3==3.7.5, python3==3.7.5, kivy==2.0.0,
-        plyer, qrcode, kivy_garden.qrcode,
+        qrcode, kivy_garden.qrcode,
         ae.base, ae.files, ae.paths, ae.deep, ae.dynamicod, ae.i18n,
         ae.updater, ae.core, ae.literal, ae.console, ae.parse_date, ae.gui_app,
         ae.gui_help, ae.kivy_auto_width, ae.kivy_dyn_chi,
@@ -103,16 +101,16 @@ Additionally, all the packages and ae namespace portions required by the above p
 sideloading server life cycle
 -----------------------------
 
-To activate the sideloading server to offer a different file, specify the path (or glob file mask) of the file to be
+to activate the sideloading server to offer a different file, specify the path (or glob file mask) of the file to be
 offered/available via sideloading in the :attr:`~SideloadingMainAppMixin.sideloading_file_mask` attribute and then call
-the method :meth:`~SideloadingMainAppMixin.on_sideloading_server_start`. This method will check if the specified file
-exists and if yes then it will start the sideloading server. If you specify a file mask instead of a concrete file path
+the method :meth:`~SideloadingMainAppMixin.on_sideloading_server_start`. this method will check if the specified file
+exists and if yes then it will start the sideloading server. if you specify a file mask instead of a concrete file path
 then this method will check if exists exactly one file matching the file mask.
 
-After the start of the sideloading server the :attr:`~SideloadingMainAppMixin.sideloading_file_ext` attribute will
+after the start of the sideloading server the :attr:`~SideloadingMainAppMixin.sideloading_file_ext` attribute will
 contain the file extension of the file available via sideloading.
 
-The sideloading server will automatically be shut down on quit/close of the embedding app. You can alternatively stop
+the sideloading server will automatically be shut down on quit/close of the embedding app. you can alternatively stop
 the sideloading server manually at any time by calling the :meth:`~SideloadingMainAppMixin.on_sideloading_server_stop`
 method.
 """
@@ -120,63 +118,38 @@ import os
 
 from typing import Callable, List, Optional
 
-from kivy.app import App                                                                        # type: ignore
-from kivy.clock import mainthread                                                               # type: ignore
-from kivy.lang import Builder                                                                   # type: ignore
-from kivy.uix.widget import Widget                                                              # type: ignore
+from kivy.app import App                                                                    # type: ignore
+from kivy.clock import mainthread                                                           # type: ignore
+from kivy.lang import Builder                                                               # type: ignore
+from kivy.uix.widget import Widget                                                          # type: ignore
 
-from ae.files import file_transfer_progress                                                     # type: ignore
-from ae.i18n import register_package_translations                                               # type: ignore
-from ae.sideloading_server import (                                                             # type: ignore
+from ae.files import file_transfer_progress                                                 # type: ignore
+from ae.i18n import register_package_translations                                           # type: ignore
+from ae.sideloading_server import (                                                         # type: ignore
     DEFAULT_FILE_MASK, FILE_COUNT_MISMATCH, server_factory, update_handler_progress, SideloadingServerApp)
-from ae.gui_app import (                                                                        # type: ignore
+from ae.gui_app import (                                                                    # type: ignore
     APP_STATE_SECTION_NAME, EventKwargsType, id_of_flow, register_package_images, update_tap_kwargs)
-from ae.gui_help import HelpAppBase, TourDropdownFromButton                                     # type: ignore
-from ae.kivy.widgets import FlowDropDown                                                        # type: ignore
-from ae.kivy.i18n import get_txt                                                                # type: ignore
+from ae.gui_help import HelpAppBase, TourDropdownFromButton                                 # type: ignore
+from ae.kivy.widgets import FlowDropDown                                                    # type: ignore
+from ae.kivy.i18n import get_txt                                                            # type: ignore
+
+import ae.kivy_file_chooser                                                                 # type: ignore # noqa: F401
+import ae.kivy_iterable_displayer                                                           # type: ignore # noqa: F401
+import ae.kivy_qr_displayer                                                                 # type: ignore # noqa: F401
 
 
-__version__ = '0.3.19'
+__version__ = '0.3.20'
 
 
 register_package_images()
 register_package_translations()
 
 
-Builder.load_string('''\
-#: import _f_ ae.kivy_file_chooser
-#: import _i_ ae.kivy_iterable_displayer
-#: import _q_ ae.kivy_qr_displayer
-
-<SideloadingMenuPopup>
-
-<SideloadingButton@FlowButton>
-    tap_flow_id:
-        id_of_flow('open', 'sideloading_menu') if app.app_states['sideloading_active'] else \
-        id_of_flow('start', 'sideloading_server')
-    tap_kwargs: update_tap_kwargs(self)
-    on_alt_tap: app.main_app.change_flow(id_of_flow('open', 'sideloading_menu'), **update_tap_kwargs(self))
-    text: app.main_app.sideloading_file_ext if app.app_states['sideloading_active'] else ""
-    source:
-        "" if app.app_states['sideloading_active'] else \
-        app.main_app.img_file('sideloading_activate', app.app_states['font_size'], \
-        app.app_states['light_theme'])
-    size_hint_x: None
-    width: self.height * (3.3 if app.landscape else 2.1)
-    _progress: app.app_states['sideloading_active']
-    ellipse_fill_ink: app.font_color[:3] + [0.69]
-    ellipse_fill_pos: self.x, self.top - app.app_states['font_size'] / 3.0
-    ellipse_fill_size: self.width * (self._progress and self._progress[0] or 0), app.app_states['font_size'] / 3.0
-    square_fill_ink: app.font_color[:3] + [0.69]
-    square_fill_pos: self.pos
-    square_fill_size: self.width * (self._progress and self._progress[1] or 0), app.app_states['font_size'] / 3.0
-    relief_square_inner_colors:
-        relief_colors((1.0, 1.0, 0.3) if app.app_states['sideloading_active'] else (1.0, 1.0, 1.0))
-    relief_square_inner_lines: int(self.height / (3.6 if app.app_states['sideloading_active'] else 2.1))
-''')
+# load/declare package widgets
+Builder.load_file(os.path.join(os.path.dirname(__file__), "widgets.kv"))
 
 
-class SideloadingMenuPopup(FlowDropDown):                                                           # pragma: no cover
+class SideloadingMenuPopup(FlowDropDown):                                                   # pragma: no cover
     """ dropdown menu to control sideloading server. """
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -224,14 +197,14 @@ class SideloadingMenuPopup(FlowDropDown):
                             tap_widget=sideloading_button))))
 
 
-class SideloadingMenuTour(TourDropdownFromButton):                                                  # pragma: no cover
+class SideloadingMenuTour(TourDropdownFromButton):                                          # pragma: no cover
     """ user preferences menu tour. """
     def __init__(self, main_app: HelpAppBase):
         super().__init__(main_app)
         self.page_ids = [id_of_flow('open', 'sideloading_menu'), TourDropdownFromButton.determine_page_ids]
 
 
-class SideloadingMainAppMixin:                                                                      # pragma: no cover
+class SideloadingMainAppMixin:                                                              # pragma: no cover
     """ mixin class with default methods for the main app class. """
     # abstract attributes/properties and methods provided by the main app instance where this get mixed into
     app_name: str
@@ -376,7 +349,7 @@ class SideloadingMainAppMixin:
 
         :param _flow_key:       unused/empty flow key.
         :param _event_kwargs:   unused event kwargs.
-        :return:                always True to confirm change of flow id.
+        :re change of flow id.
         """
         self.vpo("SideloadingMainAppMixin.on_sideloading_server_stop")
 
